aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/main/kotlin/pl/treksoft/kvision/utils/Utils.kt5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/main/kotlin/pl/treksoft/kvision/utils/Utils.kt b/src/main/kotlin/pl/treksoft/kvision/utils/Utils.kt
index e252d672..778210ab 100644
--- a/src/main/kotlin/pl/treksoft/kvision/utils/Utils.kt
+++ b/src/main/kotlin/pl/treksoft/kvision/utils/Utils.kt
@@ -23,7 +23,6 @@
package pl.treksoft.kvision.utils
-import com.lightningkite.kotlin.observable.list.ObservableList
import kotlinx.coroutines.suspendCancellableCoroutine
import org.w3c.files.File
import org.w3c.files.FileReader
@@ -206,9 +205,9 @@ suspend fun File.getContent(): String = suspendCancellableCoroutine { cont ->
}
/**
* Utility extension function to synchronise elements of the ObservableList.
*/
-fun <T> ObservableList<T>.syncWithList(list: List<T>) {
+fun <T> MutableList<T>.syncWithList(list: List<T>) {
if (list.isEmpty()) {
this.clear()
} else {
@@ -206,9 +205,9 @@ suspend fun File.getContent(): String = suspendCancellableCoroutine { cont ->
}
/**
- * Utility extension function to synchronise elements of the ObservableList.
+ * Utility extension function to synchronise elements of the MutableList.
*/